# Importing Fact Sheet Data Through Excel File
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#overview)
  * [Limitations](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#limitations)
  * [Step 1: Create an Import Template](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#step-1:-create-an-import-template)
  * [ReadMe Sheet in Template](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#readme-sheet-in-template)
  * [Step 2: Update the Data in the Spreadsheet](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#step-2:-update-the-data-in-the-spreadsheet)
  * [Key Concepts and Formatting Rules](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#key-concepts-and-formatting-rules)
  * [Overwrite Principle](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#overwrite-principle)
  * [Read-Only Fields](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file#read-only-fields)


View all
SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.
